@@ -30,14 +30,14 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <string.h>
 #include <fitsio.h>
 
-#include <nproc.h>               /* From Gnulib.                   */
-
 #include <gnuastro/fits.h>
-#include <gnuastro/timing.h>     /* Includes time.h and sys/time.h */
-#include <gnuastro/checkset.h>
-#include <gnuastro/commonargs.h>
-#include <gnuastro/configfiles.h>
-#include <gnuastro/fixedstringmacros.h>
+
+#include <nproc.h>               /* From Gnulib.                   */
+#include <timing.h>              /* Includes time.h and sys/time.h */
+#include <checkset.h>
+#include <commonargs.h>
+#include <configfiles.h>
+#include <fixedstringmacros.h>
 
 #include "main.h"
 
@@ -89,7 +89,7 @@ readconfig(char *filename, struct imgarithparams *p)
   errno=0;
   line=malloc(len*sizeof *line);
   if(line==NULL)
-    error(EXIT_FAILURE, errno, "ui.c: %lu bytes in readdefaults",
+    error(EXIT_FAILURE, errno, "ui.c: %zu bytes in readdefaults",
           len * sizeof *line);
 
   /* Read the tokens in the file:  */
@@ -213,7 +213,7 @@ checkifset(struct imgarithparams *p)
      then re-run arithmetic. The best way is to simply ignore them. */
   if(numhdus<p->numfits)
     {
-      sprintf(comment, "hdu (%lu FITS file(s), %lu HDUs)",
+      sprintf(comment, "hdu (%zu FITS file(s), %zu HDUs)",
               p->numfits, numhdus);
       GAL_CONFIGFILES_REPORT_NOTSET(comment);
     }
