@@ -23,8 +23,8 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #ifndef ARGS_H
 #define ARGS_H
 
-#include <gnuastro/commonargs.h>
-#include <gnuastro/fixedstringmacros.h>
+#include <commonargs.h>
+#include <fixedstringmacros.h>
 
 #include "ui.h"
 
