@@ -34,11 +34,12 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <gsl/gsl_const_mksa.h>
 
 #include <gnuastro/fits.h>
-#include <gnuastro/timing.h>     /* Includes time.h and sys/time.h */
-#include <gnuastro/checkset.h>
 #include <gnuastro/txtarray.h>
-#include <gnuastro/commonargs.h>
-#include <gnuastro/configfiles.h>
+
+#include <timing.h>     /* Includes time.h and sys/time.h */
+#include <checkset.h>
+#include <commonargs.h>
+#include <configfiles.h>
 
 #include "main.h"
 
@@ -89,7 +90,7 @@ readconfig(char *filename, struct cosmiccalparams *p)
   errno=0;
   line=malloc(len*sizeof *line);
   if(line==NULL)
-    error(EXIT_FAILURE, errno, "ui.c: %lu bytes in readdefaults",
+    error(EXIT_FAILURE, errno, "ui.c: %zu bytes in readdefaults",
           len * sizeof *line);
 
   /* Read the tokens in the file:  */
@@ -194,11 +195,11 @@ printvalues(FILE *fp, struct cosmiccalparams *p)
 
   fprintf(fp, "\n# Current densities per current critical density:\n");
   if(up->olambdaset)
-    fprintf(fp, CONF_SHOWFMT"%.3f\n", "olambda", p->olambda);
+    fprintf(fp, CONF_SHOWFMT"%.5f\n", "olambda", p->olambda);
   if(up->omatterset)
-    fprintf(fp, CONF_SHOWFMT"%.3f\n", "omatter", p->omatter);
+    fprintf(fp, CONF_SHOWFMT"%.5f\n", "omatter", p->omatter);
   if(up->oradiationset)
-    fprintf(fp, CONF_SHOWFMT"%.3f\n", "oradiation", p->oradiation);
+    fprintf(fp, CONF_SHOWFMT"%.5f\n", "oradiation", p->oradiation);
 
 
   /* For the operating mode, first put the macro to print the common
