@@ -30,15 +30,15 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <string.h>
 #include <fitsio.h>
 
-#include <nproc.h>               /* From Gnulib.                   */
-
 #include <gnuastro/fits.h>
-#include <gnuastro/timing.h>     /* Includes time.h and sys/time.h */
-#include <gnuastro/checkset.h>
 #include <gnuastro/txtarray.h>
 #include <gnuastro/statistics.h>
-#include <gnuastro/commonargs.h>
-#include <gnuastro/configfiles.h>
+
+#include <nproc.h>               /* From Gnulib.                   */
+#include <timing.h>              /* Includes time.h and sys/time.h */
+#include <checkset.h>
+#include <commonargs.h>
+#include <configfiles.h>
 
 #include "main.h"
 
@@ -90,7 +90,7 @@ readconfig(char *filename, struct mkcatalogparams *p)
   errno=0;
   line=malloc(len*sizeof *line);
   if(line==NULL)
-    error(EXIT_FAILURE, errno, "ui.c: %lu bytes in readdefaults",
+    error(EXIT_FAILURE, errno, "ui.c: %zu bytes in readdefaults",
           len * sizeof *line);
 
   /* Read the tokens in the file:  */
@@ -157,6 +157,7 @@ readconfig(char *filename, struct mkcatalogparams *p)
         }
 
 
+
       /* Outputs */
       else if(strcmp(name, "output")==0)
         gal_checkset_allocate_copy_set(value, &cp->output,
@@ -205,6 +206,51 @@ readconfig(char *filename, struct mkcatalogparams *p)
         }
 
 
+      /* Upper limit magnitude */
+      else if (strcmp(name, "upmaskname")==0)
+        gal_checkset_allocate_copy_set(value, &up->upmaskname,
+                                       &up->upmasknameset);
+      else if (strcmp(name, "upmaskhdu")==0)
+        gal_checkset_allocate_copy_set(value, &up->upmaskhdu,
+                                       &up->upmaskhduset);
+      else if(strcmp(name, "upnum")==0)
+        {
+          if(up->upnumset) continue;
+          gal_checkset_sizet_l_zero(value, &p->upnum, name,
+                                  key, SPACK, filename, lineno);
+          up->upnumset=1;
+        }
+      else if(strcmp(name, "envseed")==0)
+        {
+          if(up->envseedset) continue;
+          gal_checkset_int_zero_or_one(value, &p->envseed, name, key,
+                                       SPACK, filename, lineno);
+          up->envseedset=1;
+        }
+      else if(strcmp(name, "upsclipmultip")==0)
+        {
+          if(up->upsclipmultipset) continue;
+          gal_checkset_float_l_0(value, &p->upsclipmultip, name,
+                                 key, SPACK, filename, lineno);
+          up->upsclipmultipset=1;
+        }
+      else if(strcmp(name, "upsclipaccu")==0)
+        {
+          if(up->upsclipaccuset) continue;
+          gal_checkset_float_l_0_s_1(value, &p->upsclipaccu, name,
+                                    key, SPACK, filename, lineno);
+          up->upsclipaccuset=1;
+        }
+      else if(strcmp(name, "upnsigma")==0)
+        {
+          if(up->upnsigmaset) continue;
+          gal_checkset_float_l_0(value, &p->upnsigma, name,
+                                 key, SPACK, filename, lineno);
+          up->upnsigmaset=1;
+        }
+
+
+
       /* Catalog columns */
       else if(strcmp(name, "id")==0)
         {
@@ -458,6 +504,15 @@ readconfig(char *filename, struct mkcatalogparams *p)
           gal_linkedlist_add_to_sll(&p->allcolsll, CATCLUMPSMAGNITUDE);
           up->clumpsmagnitudeset=1;
         }
+      else if(strcmp(name, "upperlimitmag")==0)
+        {
+          if(up->upperlimitmagset) continue;
+          gal_checkset_int_zero_or_one(value, &yes, name, key, SPACK,
+                                       filename, lineno);
+          if(!yes) continue;
+          gal_linkedlist_add_to_sll(&p->allcolsll, CATUPPERLIMITMAG);
+          up->upperlimitmagset=1;
+        }
       else if(strcmp(name, "riverave")==0)
         {
           if(up->riveraveset) continue;
@@ -640,6 +695,24 @@ printvalues(FILE *fp, struct mkcatalogparams *p)
   if(up->accuprecisionset)
     fprintf(fp, CONF_SHOWFMT"%d\n", "accuprecision", p->accuprecision);
 
+  /* Upper limit magnitude */
+  fprintf(fp, "\n# Upper limit magnitude:\n");
+  if(up->upmasknameset)
+    fprintf(fp, CONF_SHOWFMT"%s\n", "upmaskname", up->upmaskname);
+  if(up->upmaskhduset)
+    fprintf(fp, CONF_SHOWFMT"%s\n", "upmaskhdu", up->upmaskhdu);
+  if(up->upnumset)
+    fprintf(fp, CONF_SHOWFMT"%zu\n", "upnum", p->upnum);
+  if(up->envseedset)
+    fprintf(fp, CONF_SHOWFMT"%d\n", "envseed", p->envseed);
+  if(up->upsclipmultipset)
+    fprintf(fp, CONF_SHOWFMT"%.3f\n", "upsclipmultip", p->upsclipmultip);
+  if(up->upsclipaccuset)
+    fprintf(fp, CONF_SHOWFMT"%.3f\n", "upsclipaccu", p->upsclipaccu);
+  if(up->upnsigmaset)
+    fprintf(fp, CONF_SHOWFMT"%.3f\n", "upnsigma", p->upnsigma);
+
+
   /* Catalog columns, since order is important. Notice that they have
      to be printed in opposite order (because of the way they are read
      through a simple linked list). */
@@ -719,6 +792,9 @@ printvalues(FILE *fp, struct mkcatalogparams *p)
       case CATCLUMPSBRIGHTNESS:
         fprintf(fp, CONF_SHOWFMT"%d\n", "clumpsbrightness", 1);
         break;
+      case CATUPPERLIMITMAG:
+        fprintf(fp, CONF_SHOWFMT"%d\n", "upperlimitmag", 1);
+        break;
       case CATNORIVERBRIGHTNESS:
         fprintf(fp, CONF_SHOWFMT"%d\n", "noriverbrightness", 1);
         break;
@@ -767,7 +843,7 @@ printvalues(FILE *fp, struct mkcatalogparams *p)
       default:
         error(EXIT_FAILURE, 0, "a bug! Please contact us at %s so we can "
               "fix the problem. For some reason p->allcols[%d] is given "
-              "the value %lu which is not recognized in printvalues "
+              "the value %zu which is not recognized in printvalues "
               "(ui.c)", PACKAGE_BUGREPORT, i, p->allcols[i]);
       }
 
@@ -821,6 +897,19 @@ checkifset(struct mkcatalogparams *p)
   if(up->accuprecisionset==0)
     GAL_CONFIGFILES_REPORT_NOTSET("accuprecision");
 
+  /* Upper limit magnitude. */
+  if(p->up.upperlimitmagset)
+    {
+      if(p->up.upnumset==0)
+        GAL_CONFIGFILES_REPORT_NOTSET("upnum");
+      if(p->up.upsclipmultipset==0)
+        GAL_CONFIGFILES_REPORT_NOTSET("upsclipmultip");
+      if(p->up.upsclipaccuset==0)
+        GAL_CONFIGFILES_REPORT_NOTSET("upsclipaccu");
+      if(p->up.upnsigmaset==0)
+        GAL_CONFIGFILES_REPORT_NOTSET("upnsigma");
+    }
+
   GAL_CONFIGFILES_END_OF_NOTSET_REPORT;
 }
 
@@ -960,8 +1049,8 @@ checksetlong(struct mkcatalogparams *p, char *filename, char *hdu,
 
   /* Make sure it is the same size as the input image. */
   if(s0!=p->s0 || s1!=p->s1)
-    error(EXIT_FAILURE, 0, "%s (hdu: %s) is %lu x %lu pixels while the "
-          "%s (hdu: %s) is %lu x %lu. The images should have the same "
+    error(EXIT_FAILURE, 0, "%s (hdu: %s) is %zu x %zu pixels while the "
+          "%s (hdu: %s) is %zu x %zu. The images should have the same "
           "size", filename, hdu, s1, s0, p->up.inputname,
           p->cp.hdu, p->s1, p->s0);
 }
@@ -990,8 +1079,8 @@ checksetfloat(struct mkcatalogparams *p, char *filename, char *hdu,
 
   /* Make sure it has the same size as the image. */
   if(s0!=p->s0 || s1!=p->s1)
-    error(EXIT_FAILURE, 0, "%s (hdu: %s) is %lu x %lu pixels while the "
-          "%s (hdu: %s) is %lu x %lu. The images should have the same "
+    error(EXIT_FAILURE, 0, "%s (hdu: %s) is %zu x %zu pixels while the "
+          "%s (hdu: %s) is %zu x %zu. The images should have the same "
           "size", filename, hdu, s1, s0, p->up.inputname,
           p->cp.hdu, p->s1, p->s0);
 }
@@ -1101,11 +1190,11 @@ preparearrays(struct mkcatalogparams *p)
     error(EXIT_FAILURE, 0, "no columns specified for output");
   errno=0; p->objcols=malloc(p->allncols*sizeof *p->objcols);
   if(p->objcols==NULL)
-    error(EXIT_FAILURE, errno, "%lu bytes for p->objcols in "
+    error(EXIT_FAILURE, errno, "%zu bytes for p->objcols in "
           "preprarearrays (ui.c)", p->allncols*sizeof *p->objcols);
   errno=0; p->clumpcols=malloc(p->allncols*sizeof *p->clumpcols);
   if(p->clumpcols==NULL)
-    error(EXIT_FAILURE, errno, "%lu bytes for p->clumpcols in "
+    error(EXIT_FAILURE, errno, "%zu bytes for p->clumpcols in "
           "preprarearrays (ui.c)", p->allncols*sizeof *p->clumpcols);
 
 
@@ -1199,6 +1288,9 @@ preparearrays(struct mkcatalogparams *p)
         case CATCLUMPSBRIGHTNESS:
           p->objcols[p->objncols++] = p->allcols[i];
           break;
+        case CATUPPERLIMITMAG:
+          p->objcols[p->objncols++] = p->allcols[i];
+          break;
         case CATNORIVERBRIGHTNESS:
           p->clumpcols[p->clumpncols++] = p->allcols[i];
           break;
@@ -1257,8 +1349,8 @@ preparearrays(struct mkcatalogparams *p)
           break;
         default:
           error(EXIT_FAILURE, 0, "a bug! Please contact us at %s so we "
-                "can fix the problem. For some reason p->allcols[%lu] "
-                "is given the value %lu which is not recognized in "
+                "can fix the problem. For some reason p->allcols[%zu] "
+                "is given the value %zu which is not recognized in "
                 "preparearrays (ui.c)", PACKAGE_BUGREPORT, i,
                 p->allcols[i]);
         }
@@ -1285,8 +1377,11 @@ preparearrays(struct mkcatalogparams *p)
       checksetlong(p, p->up.objlabsname, p->up.objhdu, &p->objects);
       if(p->up.clumplabsname)
         checksetlong(p, p->up.clumplabsname, p->up.clumphdu, &p->clumps);
-      else
-        p->clumps=NULL;
+      else p->clumps=NULL;
+      if(p->up.upmasknameset)
+        checksetlong(p, p->up.upmaskname, p->up.upmaskhdu, &p->upmask);
+      else p->upmask=NULL;
+
 
       /* Read the necessary keywords. */
       readkeywords(p);
@@ -1297,7 +1392,7 @@ preparearrays(struct mkcatalogparams *p)
           errno=0;
           p->objcat=malloc(p->objncols*p->numobjects*sizeof *p->objcat);
           if(p->objcat==NULL)
-            error(EXIT_FAILURE, errno, "%lu bytes for p->objcat in "
+            error(EXIT_FAILURE, errno, "%zu bytes for p->objcat in "
                   "preprarearrays (ui.c)",
                   p->objncols*p->numobjects*sizeof *p->objcat);
         }
@@ -1308,7 +1403,7 @@ preparearrays(struct mkcatalogparams *p)
           p->clumpcat=malloc(p->clumpncols*p->numclumps
                              * sizeof *p->clumpcat);
           if(p->clumpcat==NULL)
-            error(EXIT_FAILURE, errno, "%lu bytes for p->clumpcat in "
+            error(EXIT_FAILURE, errno, "%zu bytes for p->clumpcat in "
                   "preprarearrays (ui.c)",
                   p->clumpncols*p->numclumps*sizeof *p->clumpcat);
         }
@@ -1323,11 +1418,11 @@ preparearrays(struct mkcatalogparams *p)
      zero.*/
   errno=0; p->oinfo=calloc(OCOLUMNS*(p->numobjects+1), sizeof *p->oinfo);
   if(p->oinfo==NULL)
-    error(EXIT_FAILURE, errno, "%lu bytes for p->oinfo in mkcatalog "
+    error(EXIT_FAILURE, errno, "%zu bytes for p->oinfo in mkcatalog "
           "(mkcatalog.c)", OCOLUMNS*(p->numobjects+1)*sizeof *p->oinfo);
   errno=0; p->cinfo=calloc(CCOLUMNS*(p->numclumps+1), sizeof *p->cinfo);
   if(p->cinfo==NULL)
-    error(EXIT_FAILURE, errno, "%lu bytes for p->cinfo in mkcatalog "
+    error(EXIT_FAILURE, errno, "%zu bytes for p->cinfo in mkcatalog "
           "(mkcatalog.c)", CCOLUMNS*(p->numclumps+1)*sizeof *p->cinfo);
 
   /* Set the shift values to NAN for all the objects and clumps: */
@@ -1336,6 +1431,14 @@ preparearrays(struct mkcatalogparams *p)
   for(i=1;i<=p->numclumps;++i)
     p->cinfo[i*CCOLUMNS+CPOSSHIFTX]=p->cinfo[i*CCOLUMNS+CPOSSHIFTY]=NAN;
 
+  /* Allocate the random number generator: */
+  if(p->up.upperlimitmagset)
+    {
+      gsl_rng_env_setup();
+      if(p->envseed==0)
+        gsl_rng_default_seed=gal_timing_time_based_rng_seed();
+    }
+
   /* Clean up: */
   gal_linkedlist_free_sll(p->allcolsll);
 }
@@ -1380,7 +1483,6 @@ setparams(int argc, char *argv[], struct mkcatalogparams *p)
   if(argp_parse(&thisargp, argc, argv, 0, 0, p))
     error(EXIT_FAILURE, errno, "parsing arguments");
 
-
   /* Add the user default values and save them if asked. */
   GAL_CONFIGFILES_CHECK_SET_CONFIG;
 
@@ -1394,7 +1496,6 @@ setparams(int argc, char *argv[], struct mkcatalogparams *p)
   if(p->up.inputname)
     sanitycheck(p);
 
-
   /* Make the array of input images. */
   preparearrays(p);
 
@@ -1416,6 +1517,16 @@ setparams(int argc, char *argv[], struct mkcatalogparams *p)
                p->up.clumphdu);
       printf("  - Sky     %s (hdu: %s)\n", p->up.skyname, p->up.skyhdu);
       printf("  - Sky STD %s (hdu: %s)\n", p->up.stdname, p->up.stdhdu);
+      if(p->up.upperlimitmagset)
+        {
+          if(p->up.upmasknameset)
+            printf("  - Upper limit mask: %s (hdu: %s)\n", p->up.inputname,
+                   p->cp.hdu);
+          printf("  - RNG type for upper-limit magnitude: %s\n",
+                 gsl_rng_default->name);
+          printf("  - RNG seed for upper-limit magnitude: %ld\n",
+                 gsl_rng_default_seed);
+        }
     }
 }
 
@@ -1462,6 +1573,7 @@ freeandreport(struct mkcatalogparams *p, struct timeval *t1)
   free(p->up.skyhdu);
   free(p->up.stdhdu);
   free(p->up.clumphdu);
+  if(p->upmask) free(p->upmask);
   if(p->up.mhduset) free(p->up.mhdu);
   if(p->wcs) wcsvfree(&p->nwcs, &p->wcs);
   if(p->up.skynameset) free(p->up.skyname);
