@@ -23,8 +23,8 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #ifndef ARGS_H
 #define ARGS_H
 
-#include <gnuastro/commonargs.h>
-#include <gnuastro/fixedstringmacros.h>
+#include <commonargs.h>
+#include <fixedstringmacros.h>
 
 
 
@@ -233,7 +233,7 @@ static struct argp_option options[] =
       'R',
       0,
       0,
-      "Replace overlaping profile pixels, don't add.",
+      "Replace overlapping profile pixels, don't add.",
       3
     },
     {
@@ -548,6 +548,7 @@ parse_opt(int key, char *arg, struct argp_state *state)
       break;
     case 'e':
       p->envseed=1;
+      p->up.envseedset=1;
       break;
 
    /* Catalog */
