@@ -24,7 +24,8 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #define MAIN_H
 
 #include <gnuastro/fits.h>
-#include <gnuastro/commonparams.h>
+
+#include <commonparams.h>
 
 /* Progarm name macros: */
 #define SPACK           "asttable" /* Subpackage executable name. */
@@ -43,6 +44,7 @@ struct outcolumn
   int     anynul;               /* If there is any blank characters.    */
   void   *nulval;               /* The blank value for this column.     */
   void     *data;               /* Array keeping the column data.       */
+  size_t   esize;               /* Size of each element in this column. */
   char fmt[MAX_COL_FORMAT_LENGTH];  /* format to use in printf.         */
 };
 
