@@ -30,9 +30,11 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <string.h>
 #include <unistd.h>
 
+#include <gnuastro/git.h>
 #include <gnuastro/fits.h>
-#include <gnuastro/checkset.h>
-#include <gnuastro/fixedstringmacros.h>
+
+#include "checkset.h"
+#include "fixedstringmacros.h"
 
 
 /*************************************************************
@@ -265,7 +267,7 @@ gal_fits_datatype_blank(int datatype)
     case TBYTE:
       b=malloc(sizeof *b);
       if(b==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TBYTE",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TBYTE",
               sizeof *b);
       *b=GAL_FITS_BYTE_BLANK;
       return b;
@@ -276,7 +278,7 @@ gal_fits_datatype_blank(int datatype)
     case TLOGICAL: case TSBYTE:
       c=malloc(sizeof *c);
       if(c==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TLOGICAL, or TSBYTE",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TLOGICAL, or TSBYTE",
               sizeof *c);
       *c=GAL_FITS_LOGICAL_BLANK;
       return c;
@@ -284,7 +286,7 @@ gal_fits_datatype_blank(int datatype)
     case TSTRING:
       str=malloc(sizeof *str);
       if(str==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TSTRING",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TSTRING",
               sizeof *s);
       *str=GAL_FITS_STRING_BLANK;
       return str;
@@ -292,7 +294,7 @@ gal_fits_datatype_blank(int datatype)
     case TSHORT:
       s=malloc(sizeof *s);
       if(s==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TSHORT",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TSHORT",
               sizeof *s);
       *s=GAL_FITS_SHORT_BLANK;
       return s;
@@ -300,7 +302,7 @@ gal_fits_datatype_blank(int datatype)
     case TLONG:
       l=malloc(sizeof *l);
       if(l==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TLONG",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TLONG",
               sizeof *l);
       *l=GAL_FITS_LONG_BLANK;
       return l;
@@ -308,7 +310,7 @@ gal_fits_datatype_blank(int datatype)
     case TLONGLONG:
       L=malloc(sizeof *L);
       if(L==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TLONGLONG",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TLONGLONG",
               sizeof *L);
       *L=GAL_FITS_LLONG_BLANK;
       return L;
@@ -316,7 +318,7 @@ gal_fits_datatype_blank(int datatype)
     case TFLOAT:
       f=malloc(sizeof *f);
       if(f==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TFLOAT",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TFLOAT",
               sizeof *f);
       *f=GAL_FITS_FLOAT_BLANK;
       return f;
@@ -324,7 +326,7 @@ gal_fits_datatype_blank(int datatype)
     case TDOUBLE:
       d=malloc(sizeof *d);
       if(d==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TDOUBLE",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TDOUBLE",
               sizeof *d);
       *d=GAL_FITS_DOUBLE_BLANK;
       return d;
@@ -332,7 +334,7 @@ gal_fits_datatype_blank(int datatype)
     case TCOMPLEX:
       cx=malloc(sizeof *cx);
       if(cx==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TCOMPLEX",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TCOMPLEX",
               sizeof *cx);
       GSL_SET_COMPLEX(cx,GAL_FITS_FLOAT_BLANK,GAL_FITS_FLOAT_BLANK);
       return cx;
@@ -340,7 +342,7 @@ gal_fits_datatype_blank(int datatype)
     case TDBLCOMPLEX:
       dcx=malloc(sizeof *dcx);
       if(dcx==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TDBLCOMPLEX",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TDBLCOMPLEX",
               sizeof *dcx);
       GSL_SET_COMPLEX(dcx,GAL_FITS_DOUBLE_BLANK,GAL_FITS_DOUBLE_BLANK);
       return dcx;
@@ -348,7 +350,7 @@ gal_fits_datatype_blank(int datatype)
     case TINT:
       i=malloc(sizeof *i);
       if(i==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TINT",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TINT",
               sizeof *i);
       *i=GAL_FITS_INT_BLANK;
       return i;
@@ -356,7 +358,7 @@ gal_fits_datatype_blank(int datatype)
     case TUINT:
       ui=malloc(sizeof *ui);
       if(ui==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TUINT",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TUINT",
               sizeof *ui);
       *ui=GAL_FITS_UINT_BLANK;
       return ui;
@@ -364,7 +366,7 @@ gal_fits_datatype_blank(int datatype)
     case TUSHORT:
       us=malloc(sizeof *us);
       if(us==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TUSHORT",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TUSHORT",
               sizeof *us);
       *us=GAL_FITS_USHORT_BLANK;
       return us;
@@ -372,7 +374,7 @@ gal_fits_datatype_blank(int datatype)
     case TULONG:
       ul=malloc(sizeof *ul);
       if(ul==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes for blank TULONG",
+        error(EXIT_FAILURE, errno, "%zu bytes for blank TULONG",
               sizeof *ul);
       *ul=GAL_FITS_ULONG_BLANK;
       return ul;
@@ -390,7 +392,7 @@ gal_fits_datatype_blank(int datatype)
 
 
 
-/* Allocate an array based on the value of bitpix. Note that the argument
+/* Allocate an array based on the value of datatype. Note that the argument
    `size' is the number of elements, necessary in the array, the number of
    bytes each element needs will be determined internaly by this function
    using the datatype argument, so you don't have to worry about it. */
@@ -491,7 +493,7 @@ gal_fits_datatype_alloc(size_t size, int datatype)
   array=malloc(size);
   if(array==NULL)
     error(EXIT_FAILURE, errno,
-          "array of %lu bytes in gal_fits_datatype_alloc", size);
+          "array of %zu bytes in gal_fits_datatype_alloc", size);
 
   return array;
 }
@@ -500,6 +502,89 @@ gal_fits_datatype_alloc(size_t size, int datatype)
 
 
 
+size_t
+gal_fits_datatype_size(int datatype)
+{
+  switch(datatype)
+    {
+    case TBIT:
+      error(EXIT_FAILURE, 0, "Currently Gnuastro doesn't support TBIT "
+            "datatype, please get in touch with us to implement it.");
+
+      /* The parenthesis after sizeof is not a function, it is actually a
+         type cast, so we have put a space between size of and the
+         parenthesis to highlight this. In C, `sizeof' is an operator, not
+         a function.*/
+    case TBYTE:
+      return sizeof (unsigned char);
+
+    case TLOGICAL: case TSBYTE:
+      return sizeof (char);
+
+    case TSTRING:
+      return sizeof (char *);
+
+    case TSHORT:
+      return sizeof (short);
+
+    case TLONG:
+      return sizeof (long);
+
+    case TLONGLONG:
+      return sizeof (LONGLONG);
+
+    case TFLOAT:
+      if( sizeof (float) != 4 )
+        error(EXIT_FAILURE, 0,
+              "`float` is not 32bits on this machine. The FITS standard "
+              "Requires this size");
+      return sizeof (float);
+
+    case TDOUBLE:
+      if( sizeof (double) != 8 )
+        error(EXIT_FAILURE, 0,
+              "`double` is not 64bits on this machine. The FITS standard "
+              "requires this size");
+      return sizeof (double);
+
+    case TCOMPLEX:
+      if( sizeof (float) != 4 )
+        error(EXIT_FAILURE, 0,
+              "`float` is not 32bits on this machine. The FITS standard "
+              "Requires this size");
+      return sizeof (gsl_complex_float);
+
+    case TDBLCOMPLEX:
+      if( sizeof (double) != 8 )
+        error(EXIT_FAILURE, 0,
+              "`double` is not 64bits on this machine. The FITS standard "
+              "requires this size");
+      return sizeof (gsl_complex);
+
+    case TINT:
+      return sizeof (int);
+
+    case TUINT:
+      return sizeof (unsigned int);
+
+    case TUSHORT:
+      return sizeof (unsigned short);
+
+    case TULONG:
+      return sizeof (unsigned long);
+
+    default:
+      error(EXIT_FAILURE, 0, "datatype value of %d not recognized in "
+            "gal_fits_datatype_size", datatype);
+    }
+
+  return 0;
+}
+
+
+
+
+
 void
 gal_fits_blank_to_value(void *array, int datatype, size_t size, void *value)
 {
@@ -1045,7 +1130,7 @@ gal_fits_read_hdu(char *filename, char *hdu, unsigned char img0_tab1,
   len=strlen(filename)+strlen(hdu)+4;
   ffname=malloc(len*sizeof *ffname);
   if(ffname==NULL)
-    error(EXIT_FAILURE, errno, "%lu characters", len);
+    error(EXIT_FAILURE, errno, "%zu characters", len);
   sprintf(ffname, "%s[%s#]", filename, hdu);
 
   /* Open the FITS file: */
@@ -1110,7 +1195,7 @@ gal_fits_read_keywords(char *filename, char *hdu, struct gal_fits_key *keys,
   len=strlen(filename)+strlen(hdu)+4;
   ffname=malloc(len*sizeof *ffname);
   if(ffname==NULL)
-    error(EXIT_FAILURE, errno, "%lu characters", len);
+    error(EXIT_FAILURE, errno, "%zu characters", len);
   sprintf(ffname, "%s[%s#]", filename, hdu);
 
   /* Open the FITS file: */
@@ -1148,7 +1233,7 @@ gal_fits_read_keywords(char *filename, char *hdu, struct gal_fits_key *keys,
           valueptr=&keys[i].d;
           break;
         default:
-          error(EXIT_FAILURE, 0, "the value of keys[%lu].datatype (=%d) "
+          error(EXIT_FAILURE, 0, "the value of keys[%zu].datatype (=%d) "
                 "is not recognized", i, keys[i].datatype);
         }
 
@@ -1299,14 +1384,14 @@ gal_fits_file_name_in_keywords(char *keynamebase, char *filename,
       keyname=malloc(FLEN_KEYWORD);
       if(keyname==NULL)
         error(EXIT_FAILURE, errno, "%d bytes", FLEN_KEYWORD);
-      sprintf(keyname, "%s_%lu", keynamebase, numkey++);
+      sprintf(keyname, "%s_%zu", keynamebase, numkey++);
 
       /* Set the keyword value: */
       errno=0;
       thislen=strlen(&filename[i]);
       value=malloc(maxlength);
       if(value==NULL)
-        error(EXIT_FAILURE, errno, "%lu bytes", thislen);
+        error(EXIT_FAILURE, errno, "%zu bytes", thislen);
       strncpy(value, &filename[i], maxlength);
 
       /* If the FROM string (=&filename[i]) in strncpy is shorter than
@@ -1332,7 +1417,7 @@ gal_fits_file_name_in_keywords(char *keynamebase, char *filename,
               }
           if(j==0)
             error(EXIT_FAILURE, 0, "the filename `%sP has at least one "
-                  "span of %lu characters without a `/`. It cannot be "
+                  "span of %zu characters without a `/`. It cannot be "
                   "written to the header of the output fits file",
                   filename, maxlength);
 
@@ -1436,6 +1521,7 @@ gal_fits_write_keys_version(fitsfile *fptr, struct gal_fits_key_ll *headers,
 {
   size_t i;
   int status=0;
+  char *gitdescribe;
   char cfitsioversion[20];
   char startblank[]="              / ";
   char *cp, *cpf, blankrec[80], titlerec[80];
@@ -1444,7 +1530,7 @@ gal_fits_write_keys_version(fitsfile *fptr, struct gal_fits_key_ll *headers,
      defined. Sometime in the future were everyone has moved to more
      recent versions of WCSLIB, we can remove this macro and its check
      in configure.ac.*/
-#ifdef HAVE_WCSLIBVERSION
+#ifdef HAVE_WCSLIB_VERSION
   int wcslibvers[3];
   char wcslibversion[20];
   const char *wcslibversion_const;
@@ -1456,38 +1542,57 @@ gal_fits_write_keys_version(fitsfile *fptr, struct gal_fits_key_ll *headers,
   titlerec[79]='\0';
   cp=blankrec; do *cp=' '; while(++cp<cpf);
 
-  /*Print the starting information for the header.  */
+  /* If any header keywords are specified add them: */
+  if(headers)
+    {
+      fits_write_record(fptr, blankrec, &status);
+      sprintf(titlerec, "%s%s", startblank, spack_string);
+      for(i=strlen(titlerec);i<79;++i) titlerec[i]=' ';
+      fits_write_record(fptr, titlerec, &status);
+      gal_fits_update_keys(fptr, &headers);
+    }
+
+
+  /* Start printing the version information */
   fits_write_record(fptr, blankrec, &status);
-  sprintf(titlerec, "%s%s:", startblank, spack_string);
+  sprintf(titlerec, "%sVersions and date", startblank);
   for(i=strlen(titlerec);i<79;++i) titlerec[i]=' ';
   fits_write_record(fptr, titlerec, &status);
   gal_fits_io_error(status, NULL);
 
-  /* If any header keywords are specified add them: */
-  if(headers)
-    gal_fits_update_keys(fptr, &headers);
-
   /* Set the version of CFITSIO as a string. */
   sprintf(cfitsioversion, "%-.2f", CFITSIO_VERSION);
 
   /* Write all the information: */
   fits_write_date(fptr, &status);
+
+  /* Write the version of CFITSIO */
   fits_update_key(fptr, TSTRING, "CFITSIO", cfitsioversion,
                   "CFITSIO version.", &status);
-#ifdef HAVE_WCSLIBVERSION
+
+  /* Write the WCSLIB version */
+#ifdef HAVE_WCSLIB_VERSION
   wcslibversion_const=wcslib_version(wcslibvers);
   strcpy(wcslibversion, wcslibversion_const);
   fits_update_key(fptr, TSTRING, "WCSLIB", wcslibversion,
                   "WCSLIB version.", &status);
 #endif
+
+  /* Write the Gnuastro version. */
   fits_update_key(fptr, TSTRING, "GNUASTRO", PACKAGE_VERSION,
                   "GNU Astronomy Utilities version.", &status);
-  fits_write_comment(fptr, PACKAGE_STRING, &status);
-  fits_write_comment(fptr, PACKAGE_URL, &status);
-  /*
-  fits_write_comment(fptr, GAL_STRINGS_SHORT_COPYRIGHT, &status);
-  fits_write_comment(fptr, GAL_STRINGS_SHORT_LICENSE, &status);
-  */
+
+  /* If we are in a version controlled directory and have libgit2
+     installed, write the commit description into the FITS file. */
+  gitdescribe=gal_git_describe();
+  if(gitdescribe)
+    {
+      fits_update_key(fptr, TSTRING, "COMMIT", gitdescribe,
+                      "Git's commit description in running dir.", &status);
+      free(gitdescribe);
+    }
+
+  /* Report any error if a problem came up */
   gal_fits_io_error(status, NULL);
 }
 
@@ -1992,7 +2097,7 @@ gal_fits_file_to_float(char *inputname, char *maskname, char *inhdu,
 
       if(s0!=*ins0 || s1!=*ins1)
         error(EXIT_FAILURE, 0, "the input image %s (hdu: %s) has size: "
-              "%lu x %lu. The mask image %s (hdu: %s) has size %lu x %lu. "
+              "%zu x %zu. The mask image %s (hdu: %s) has size %zu x %zu. "
               "The two images have to have the same size", inputname,
               inhdu, *ins1, *ins0, maskname, mhdu, s1, s0);
 
@@ -2057,7 +2162,7 @@ gal_fits_file_to_double(char *inputname, char *maskname, char *inhdu,
 
       if(s0!=*ins0 || s1!=*ins1)
         error(EXIT_FAILURE, 0, "the input image %s (hdu: %s) has size: "
-              "%lu x %lu. The mask image %s (hdu: %s) has size %lu x %lu. "
+              "%zu x %zu. The mask image %s (hdu: %s) has size %zu x %zu. "
               "The two images have to have the same size", inputname,
               inhdu, *ins1, *ins0, maskname, mhdu, s1, s0);
 
@@ -2125,7 +2230,7 @@ gal_fits_prep_float_kernel(char *inputname, char *inhdu, float **outkernel,
   if(*ins0%2==0 || *ins1%2==0)
     error(EXIT_FAILURE, 0, "the kernel image has to have an odd number "
           "of pixels on both sides (there has to be on pixel in the "
-          "center). %s (hdu: %s) is %lu by %lu", inputname, inhdu,
+          "center). %s (hdu: %s) is %zu by %zu", inputname, inhdu,
           *ins1, *ins0);
 
   /* If there are any NaN pixels, set them to zero and normalize it.*/
